{% extends 'admin_boilerplate/base_admin.html' %}

{% block content %}
<h2>Admin Login</h2>
<form method="post">
    {% csrf_token %}
    <label>Username:</label>
    <input type="text" name="username" required>
    <label>Password:</label>
    <input type="password" name="password" required>
    <button type="submit">Login</button>
</form>
{% endblock %}
